@@ -260,12 +260,6 @@ _falconx_sandbox_endpoints = [
     "Retrieves the file associated with the given ID (SHA256)",
     "falconx_sandbox",
     [
-      {
-        "type": "string",
-        "description": "User UUID",
-        "name": "X-CS-USERUUID",
-        "in": "header"
-      },
       {
         "type": "string",
         "description": "The file SHA256.",
@@ -274,7 +268,7 @@ _falconx_sandbox_endpoints = [
         "required": True
       },
       {
-        "type": "string",
+        "type": "boolean",
         "default": False,
         "description": "Flag whether the sample should be zipped and password protected with pass='infected'",
         "name": "password_protected",
@@ -289,12 +283,6 @@ _falconx_sandbox_endpoints = [
     "Upload a file for sandbox analysis. After uploading, use `/falconx/entities/submissions/v1` to start analyzing the file.",
     "falconx_sandbox",
     [
-      {
-        "type": "string",
-        "description": "User UUID",
-        "name": "X-CS-USERUUID",
-        "in": "header"
-      },
       {
         "description": "Content of the uploaded sample in binary format. "
         "For example, use `--data-binary @$FILE_PATH` when using cURL. Max file size: 100 MB.\n\n"
@@ -320,14 +308,14 @@ _falconx_sandbox_endpoints = [
         "type": "string",
         "description": "Name of the file.",
         "name": "file_name",
-        "in": "query",
+        "in": "formData",
         "required": True
       },
       {
         "type": "string",
         "description": "A descriptive comment to identify the file for other users.",
         "name": "comment",
-        "in": "query"
+        "in": "formData"
       },
       {
         "type": "boolean",
@@ -336,7 +324,7 @@ _falconx_sandbox_endpoints = [
         "Falcon console.\n\n- `true`: File is only shown to users within your customer account\n- `false`: "
         "File can be seen by other CrowdStrike customers \n\nDefault: `true`.",
         "name": "is_confidential",
-        "in": "query"
+        "in": "formData"
       }
     ]
   ],
@@ -347,12 +335,6 @@ _falconx_sandbox_endpoints = [
     "Removes a sample, including file, meta and submissions from the collection",
     "falconx_sandbox",
     [
-      {
-        "type": "string",
-        "description": "User UUID",
-        "name": "X-CS-USERUUID",
-        "in": "header"
-      },
       {
         "type": "string",
         "description": "The file SHA256.",
@@ -370,12 +352,6 @@ _falconx_sandbox_endpoints = [
     "maximum number of accepted items is 200",
     "falconx_sandbox",
     [
-      {
-        "type": "string",
-        "description": "User UUID",
-        "name": "X-CS-USERUUID",
-        "in": "header"
-      },
       {
         "description": "Pass a list of sha256s to check if the exist. It will be returned the list of existing hashes.",
         "name": "body",
